@@ -18,6 +18,6 @@
 
 #define NL_MAJOR 2
 #define NL_MINOR 0
-#define NL_REV   9
-#define NL_DATE  "Mar 23, 2004"
-#define VERSION  "2.0.9"
+#define NL_REV   10
+#define NL_DATE  "Sep 03, 2004"
+#define VERSION  "2.0.10"
